@@ -9,17 +9,19 @@ use Padre::Action::Help     ();
 use Padre::Action::Perl     ();
 use Padre::Action::Plugins  ();
 use Padre::Action::Refactor ();
+use Padre::Action::Debugger ();
 use Padre::Action::Run      ();
 use Padre::Action::Search   ();
 use Padre::Action::Window   ();
 use Padre::Action::Internal ();
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 # Generate faster accessors
 use Class::XSAccessor getters => {
 	id            => 'id',
 	icon          => 'icon',
+	comment       => 'comment',
 	name          => 'name',
 	label         => 'label',
 	shortcut      => 'shortcut',
@@ -41,6 +43,7 @@ sub create {
 	Padre::Action::Perl->new($main);
 	Padre::Action::Plugins->new($main);
 	Padre::Action::Refactor->new($main);
+	Padre::Action::Debugger->new($main);
 	Padre::Action::Run->new($main);
 	Padre::Action::Search->new($main);
 	Padre::Action::Window->new($main);
