@@ -8,7 +8,7 @@ use warnings;
 use Padre::Action;
 use Padre::Current qw{_CURRENT};
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 our @ISA     = 'Padre::Wx::Menu';
 
 #####################################################################
@@ -29,6 +29,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'window.last_visited_file',
 		label       => Wx::gettext('Last Visited File'),
+		comment     => Wx::gettext('Switch to edit the file that was previously edited (can switch back and forth)'),
 		shortcut    => 'Ctrl-Tab',
 		need_editor => 1,
 		menu_event  => sub {
@@ -39,6 +40,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'window.oldest_visited_file',
 		label       => Wx::gettext('Oldest Visited File'),
+		comment     => Wx::gettext('Put focus on tab visited the longest time ago.'),
 		shortcut    => 'Ctrl-Shift-Tab',
 		need_editor => 1,
 		menu_event  => sub {
@@ -49,6 +51,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'window.next_file',
 		label       => Wx::gettext('Next File'),
+		comment     => Wx::gettext('Put focus on the next tab to the right'),
 		shortcut    => 'Alt-Right',
 		need_editor => 1,
 		menu_event  => sub {
@@ -59,6 +62,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'window.previous_file',
 		label       => Wx::gettext('Previous File'),
+		comment     => Wx::gettext('Put focus on the previous tab to the left'),
 		shortcut    => 'Alt-Left',
 		need_editor => 1,
 		menu_event  => sub {
@@ -71,6 +75,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'window.last_visited_file_old',
 		label       => Wx::gettext('Last Visited File'),
+		comment     => Wx::gettext('???'),
 		shortcut    => 'Ctrl-Shift-P',
 		need_editor => 1,
 		menu_event  => sub {
@@ -81,6 +86,7 @@ sub new {
 	Padre::Action->new(
 		name        => 'window.right_click',
 		label       => Wx::gettext('Right Click'),
+		comment     => Wx::gettext('Imitate clicking on the right mouse button'),
 		shortcut    => 'Alt-/',
 		need_editor => 1,
 		menu_event  => sub {
@@ -95,6 +101,7 @@ sub new {
 	Padre::Action->new(
 		name       => 'window.goto_functions_window',
 		label      => Wx::gettext('GoTo Functions Window'),
+		comment    => Wx::gettext('Set the focus to be the functions window'),
 		shortcut   => 'Alt-N',
 		menu_event => sub {
 			$_[0]->refresh_functions( $_[0]->current );
@@ -106,6 +113,7 @@ sub new {
 	Padre::Action->new(
 		name       => 'window.goto_outline_window',
 		label      => Wx::gettext('GoTo Outline Window'),
+		comment    => Wx::gettext('Set the focus to be the outline window'),
 		shortcut   => 'Alt-L',
 		menu_event => sub {
 			$_[0]->show_outline(1);
@@ -116,6 +124,7 @@ sub new {
 	Padre::Action->new(
 		name       => 'window.goto_output_window',
 		label      => Wx::gettext('GoTo Output Window'),
+		comment    => Wx::gettext('Set the focus to be the output window'),
 		shortcut   => 'Alt-O',
 		menu_event => sub {
 			$_[0]->show_output(1);
@@ -126,6 +135,7 @@ sub new {
 	Padre::Action->new(
 		name       => 'window.goto_syntax_check_window',
 		label      => Wx::gettext('GoTo Syntax Check Window'),
+		comment    => Wx::gettext('Set the focus to be the syntax check window'),
 		shortcut   => 'Alt-C',
 		menu_event => sub {
 			$_[0]->show_syntax(1);
@@ -136,6 +146,7 @@ sub new {
 	Padre::Action->new(
 		name       => 'window.goto_main_window',
 		label      => Wx::gettext('GoTo Main Window'),
+		comment    => Wx::gettext('Set the focus to be the main editor window'),
 		shortcut   => 'Alt-M',
 		menu_event => sub {
 			my $editor = $_[0]->current->editor or return;
