@@ -23,7 +23,7 @@ use File::Basename ();
 use Padre::Wx      ();
 use Padre::DB      ();
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 #####################################################################
 # Document Registration
@@ -82,6 +82,7 @@ sub _initialize {
 		plx   => \&perl_mime_type,
 		pm    => \&perl_mime_type,
 		pod   => \&perl_mime_type,
+		psgi  => 'application/x-psgi',
 		t     => \&perl_mime_type,
 
 		# Lacking a better solution, define our own MIME
@@ -217,6 +218,10 @@ sub _initialize {
 			lexer => Wx::wxSTC_LEX_PERL,     # CONFIRMED
 			class => 'Padre::Document::Perl',
 		},
+		'application/x-psgi' => {
+			name  => 'PSGI',
+			lexer => Wx::wxSTC_LEX_PERL,     # CONFIRMED
+		},
 		'text/x-python' => {
 			name  => 'Python',
 			lexer => Wx::wxSTC_LEX_PYTHON,   # CONFIRMED
