@@ -7,7 +7,7 @@ use Padre::Wx      ();
 use Padre::Plugin  ();
 use Padre::Current ();
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 our @ISA     = 'Padre::Plugin';
 
 
@@ -56,7 +56,8 @@ sub plugin_disable {
 sub menu_plugins_simple {
 	my $self = shift;
 	return $self->plugin_name => [
-		Wx::gettext('Run Document inside Padre') => 'eval_document',
+		Wx::gettext('Run Document inside Padre')  => 'eval_document',
+		Wx::gettext('Run Selection inside Padre') => 'eval_selection',
 
 		'---' => undef,
 
@@ -122,6 +123,13 @@ sub eval_document {
 	return $self->_dump_eval( $document->text_get );
 }
 
+sub eval_selection {
+	my $self = shift;
+	my $document = $self->current->document or return;
+	return $self->_dump_eval( $self->current->text );
+}
+
+
 sub dump_document {
 	my $self     = shift;
 	my $current  = $self->current;
