@@ -65,7 +65,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 use Params::Util qw{_INSTANCE};
 
@@ -80,7 +80,7 @@ require Padre;
 use Padre::Task    ();
 use Padre::Service ();
 use Padre::Wx      ();
-use Padre::Debug;
+use Padre::Logger;
 
 use Class::XSAccessor getters => {
 	task_queue     => 'task_queue',
