@@ -10,7 +10,7 @@ use Padre::Wx::Editor                      ();
 use Padre::Wx::Dialog::Preferences::Editor ();
 use Padre::MimeTypes                       ();
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 our @ISA     = 'Padre::Wx::Dialog';
 
 our %PANELS = (
@@ -223,12 +223,18 @@ sub _behaviour_panel {
 	my ( $self, $treebook, $main_startup, $main_functions_order, $perldiag_locales, $default_line_ending ) = @_;
 
 	my $config = Padre->ide->config;
-	my $table  = [
+
+	my $table = [
 		[   [   'Wx::CheckBox', 'editor_wordwrap', ( $config->editor_wordwrap ? 1 : 0 ),
 				Wx::gettext('Default word wrap on for each file')
 			],
 			[]
 		],
+		[   [   'Wx::CheckBox', 'swap_ctrl_tab_alt_right', ( $config->swap_ctrl_tab_alt_right ? 1 : 0 ),
+				Wx::gettext('Use panel order for Ctrl-Tab (not usage history)')
+			],
+			[]
+		],
 		[   [   'Wx::CheckBox',
 				'save_autoclean',
 				( $config->save_autoclean ? 1 : 0 ),
@@ -957,6 +963,10 @@ sub run {
 		'editor_wordwrap',
 		$data->{editor_wordwrap} ? 1 : 0
 	);
+	$config->set(
+		'swap_ctrl_tab_alt_right',
+		$data->{swap_ctrl_tab_alt_right} ? 1 : 0
+	);
 	$config->set(
 		'save_autoclean',
 		$data->{save_autoclean} ? 1 : 0
