@@ -3,10 +3,9 @@ package Padre::Wx::Dialog::Preferences::PerlAutoComplete;
 use 5.008;
 use strict;
 use warnings;
-
 use Padre::Wx::Dialog::Preferences ();
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 our @ISA     = 'Padre::Wx::Dialog::Preferences';
 
 sub panel {
@@ -43,6 +42,13 @@ sub panel {
 			],
 			[]
 		],
+		[   [   'Wx::CheckBox',
+				'autocomplete_subroutine',
+				( $config->autocomplete_subroutine ? 1 : 0 ),
+				Wx::gettext("Autocomplete new subroutines in scripts")
+			],
+			[]
+		],
 		[   [ 'Wx::StaticText', undef, Wx::gettext('Min. length of suggestions:') ],
 			[   'Wx::SpinCtrl', 'perl_autocomplete_min_suggestion_len', $config->perl_autocomplete_min_suggestion_len,
 				1,              64
@@ -77,6 +83,10 @@ sub save {
 		'autocomplete_method',
 		$data->{autocomplete_method} ? 1 : 0
 	);
+	$config->set(
+		'autocomplete_subroutine',
+		$data->{autocomplete_subroutine} ? 1 : 0
+	);
 
 	$config->set(
 		'perl_autocomplete_max_suggestions',
@@ -95,11 +105,12 @@ sub save {
 
 }
 
-
-
 1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
 Padre::Wx::Dialog::Preferences::PerlAutoComplete
