@@ -12,7 +12,7 @@ use Padre::Wx       ();
 use Padre::Wx::Menu ();
 use Padre::Locale   ();
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 our @ISA     = 'Padre::Wx::Menu';
 
 #####################################################################
@@ -34,6 +34,7 @@ sub new {
 		$self,
 		name       => 'view.lockinterface',
 		label      => Wx::gettext('Lock User Interface'),
+		comment    => Wx::gettext('Allow the user to move around some of the windows'),
 		menu_event => sub {
 			$_[0]->on_toggle_lockinterface( $_[1] );
 		},
@@ -44,8 +45,10 @@ sub new {
 	# Show or hide GUI elements
 	$self->{output} = $self->add_checked_menu_item(
 		$self,
-		name       => 'view.output',
-		label      => Wx::gettext('Show Output'),
+		name  => 'view.output',
+		label => Wx::gettext('Show Output'),
+		comment =>
+			Wx::gettext('Show the window displaying the standard output and standar error of the running scripts'),
 		menu_event => sub {
 			$_[0]->show_output( $_[1]->IsChecked );
 		},
@@ -55,6 +58,7 @@ sub new {
 		$self,
 		name       => 'view.functions',
 		label      => Wx::gettext('Show Functions'),
+		comment    => Wx::gettext('Show a window listing all the functions in the current document'),
 		menu_event => sub {
 			if ( $_[1]->IsChecked ) {
 				$_[0]->refresh_functions( $_[0]->current );
@@ -68,8 +72,9 @@ sub new {
 	# Show or hide GUI elements
 	$self->{outline} = $self->add_checked_menu_item(
 		$self,
-		name       => 'view.outline',
-		label      => Wx::gettext('Show Outline'),
+		name    => 'view.outline',
+		label   => Wx::gettext('Show Outline'),
+		comment => Wx::gettext('Show a window listing all the parts of the current file (functions, pragmas, modules)'),
 		menu_event => sub {
 			$_[0]->show_outline( $_[1]->IsChecked );
 		},
@@ -79,6 +84,7 @@ sub new {
 		$self,
 		name       => 'view.directory',
 		label      => Wx::gettext('Show Directory Tree'),
+		comment    => Wx::gettext('Show a window with a directory browser of the current project'),
 		menu_event => sub {
 			$_[0]->show_directory( $_[1]->IsChecked );
 		},
@@ -88,6 +94,7 @@ sub new {
 		$self,
 		name       => 'view.show_syntaxcheck',
 		label      => Wx::gettext('Show Syntax Check'),
+		comment    => Wx::gettext('Turn on syntax checking of the current document and show output in a window'),
 		menu_event => sub {
 			$_[0]->on_toggle_syntax_check( $_[1] );
 		},
@@ -97,6 +104,7 @@ sub new {
 		$self,
 		name       => 'view.show_errorlist',
 		label      => Wx::gettext('Show Error List'),
+		comment    => Wx::gettext('Show the list of errors received during execution of a script'),
 		menu_event => sub {
 			$_[0]->on_toggle_errorlist( $_[1] );
 		},
@@ -105,7 +113,8 @@ sub new {
 	$self->{statusbar} = $self->add_checked_menu_item(
 		$self,
 		name       => 'view.statusbar',
-		label      => Wx::gettext('Show StatusBar'),
+		label      => Wx::gettext('Show Status Bar'),
+		comment    => Wx::gettext('Show/hide the status bar at the bottom of the screen'),
 		menu_event => sub {
 			$_[0]->on_toggle_statusbar( $_[1] );
 		},
@@ -115,6 +124,7 @@ sub new {
 		$self,
 		name       => 'view.toolbar',
 		label      => Wx::gettext('Show Toolbar'),
+		comment    => Wx::gettext('Show/hide the toolbar at the top of the editor'),
 		menu_event => sub {
 			$_[0]->on_toggle_toolbar( $_[1] );
 		},
@@ -140,6 +150,7 @@ sub new {
 			$self->{view_as_highlighting},
 			name       => $tag,
 			label      => $label,
+			comment    => sprintf( Wx::gettext('Switch document type to %s'), $label ),
 			menu_event => sub { $_[0]->set_mimetype( $mimes{$name} ) },
 		);
 	}
@@ -151,6 +162,7 @@ sub new {
 		$self,
 		name       => 'view.lines',
 		label      => Wx::gettext('Show Line Numbers'),
+		comment    => Wx::gettext('Show/hide the line numbers of all the documents on the left side of the window'),
 		menu_event => sub {
 			$_[0]->on_toggle_line_numbers( $_[1] );
 		},
@@ -158,8 +170,9 @@ sub new {
 
 	$self->{folding} = $self->add_checked_menu_item(
 		$self,
-		name       => 'view.folding',
-		label      => Wx::gettext('Show Code Folding'),
+		name    => 'view.folding',
+		label   => Wx::gettext('Show Code Folding'),
+		comment => Wx::gettext('Show/hide a vertical line on the left hand side of the window to allow folding rows'),
 		menu_event => sub {
 			$_[0]->on_toggle_code_folding( $_[1] );
 		},
@@ -169,6 +182,7 @@ sub new {
 		$self,
 		name       => 'view.show_calltips',
 		label      => Wx::gettext('Show Call Tips'),
+		comment    => Wx::gettext('When typing in functions allow showing short examples of the function'),
 		menu_event => sub {
 			$_[0]->config->set(
 				'editor_calltips',
@@ -182,6 +196,7 @@ sub new {
 		$self,
 		name       => 'view.currentline',
 		label      => Wx::gettext('Show Current Line'),
+		comment    => Wx::gettext('Highlight the line where the cursor is'),
 		menu_event => sub {
 			$_[0]->on_toggle_currentline( $_[1] );
 		},
@@ -191,6 +206,7 @@ sub new {
 		$self,
 		name       => 'view.rightmargin',
 		label      => Wx::gettext('Show Right Margin'),
+		comment    => Wx::gettext('Show a vertical line indicating the right margin'),
 		menu_event => sub {
 			$_[0]->on_toggle_right_margin( $_[1] );
 		},
@@ -203,6 +219,7 @@ sub new {
 		$self,
 		name       => 'view.eol',
 		label      => Wx::gettext('Show Newlines'),
+		comment    => Wx::gettext('Show/hide the newlines with special character'),
 		menu_event => sub {
 			$_[0]->on_toggle_eol( $_[1] );
 		},
@@ -212,6 +229,7 @@ sub new {
 		$self,
 		name       => 'view.whitespaces',
 		label      => Wx::gettext('Show Whitespaces'),
+		comment    => Wx::gettext('Show/hide the tabs and the spaces with special characters'),
 		menu_event => sub {
 			$_[0]->on_toggle_whitespaces( $_[1] );
 		},
@@ -221,6 +239,7 @@ sub new {
 		$self,
 		name       => 'view.indentation_guide',
 		label      => Wx::gettext('Show Indentation Guide'),
+		comment    => Wx::gettext('Show/hide vertical bars at every indentation position on the left of the rows'),
 		menu_event => sub {
 			$_[0]->on_toggle_indentation_guide( $_[1] );
 		},
@@ -230,6 +249,7 @@ sub new {
 		$self,
 		name       => 'view.word_wrap',
 		label      => Wx::gettext('Word-Wrap'),
+		comment    => Wx::gettext('Wrap long lines'),
 		menu_event => sub {
 			$_[0]->on_word_wrap( $_[1]->IsChecked );
 		},
@@ -249,6 +269,7 @@ sub new {
 		$self->{font_size},
 		name       => 'view.font_increase',
 		label      => Wx::gettext('Increase Font Size'),
+		comment    => Wx::gettext('Make the letters bigger in the editor window'),
 		shortcut   => 'Ctrl-+',
 		menu_event => sub {
 			$_[0]->zoom(+1);
@@ -259,6 +280,7 @@ sub new {
 		$self->{font_size},
 		name       => 'view.font_decrease',
 		label      => Wx::gettext('Decrease Font Size'),
+		comment    => Wx::gettext('Make the letters smaller in the editor window'),
 		shortcut   => 'Ctrl--',
 		menu_event => sub {
 			$_[0]->zoom(-1);
@@ -269,6 +291,7 @@ sub new {
 		$self->{font_size},
 		name       => 'view.font_reset',
 		label      => Wx::gettext('Reset Font Size'),
+		comment    => Wx::gettext('Reset the the size of the letters to the default in the editor window'),
 		shortcut   => 'Ctrl-0',
 		menu_event => sub {
 			my $editor = $_[0]->current->editor or return;
@@ -285,6 +308,7 @@ sub new {
 			$self,
 			name       => 'view.bookmark_set',
 			label      => Wx::gettext('Set Bookmark'),
+			comment    => Wx::gettext('Create a bookmark in the current file current row'),
 			shortcut   => 'Ctrl-B',
 			menu_event => sub {
 				require Padre::Wx::Dialog::Bookmarks;
@@ -296,6 +320,7 @@ sub new {
 			$self,
 			name       => 'view.bookmark_goto',
 			label      => Wx::gettext('Goto Bookmark'),
+			comment    => Wx::gettext('Select a bookmark created earlier and jump to that position'),
 			shortcut   => 'Ctrl-Shift-B',
 			menu_event => sub {
 				require Padre::Wx::Dialog::Bookmarks;
@@ -330,6 +355,7 @@ sub new {
 			$self->{style},
 			name       => $tag,
 			label      => $label,
+			comment    => sprintf( Wx::gettext('Switch highlighting colors to %s style'), $label ),
 			menu_event => sub {
 				$_[0]->change_style($name);
 			},
@@ -352,6 +378,7 @@ sub new {
 				$self->{style},
 				name       => $tag,
 				label      => $label,
+				comment    => sprintf( Wx::gettext('Switch highlighting colors to %s style'), $label ),
 				menu_event => sub {
 					$_[0]->change_style( $name, 1 );
 				},
@@ -381,6 +408,7 @@ sub new {
 		$self->{language},
 		name       => 'view.language_default',
 		label      => Wx::gettext('System Default') . " ($default)",
+		comment    => sprintf( Wx::gettext('Switch menus to the default %s'), $default ),
 		menu_event => sub {
 			$_[0]->change_locale;
 		},
@@ -414,6 +442,7 @@ sub new {
 			$self->{language},
 			name       => $tag,
 			label      => $label,
+			comment    => sprintf( Wx::gettext('Switch menus to %s'), $label ),
 			menu_event => sub {
 				$_[0]->change_locale($name);
 			},
@@ -430,6 +459,7 @@ sub new {
 		$self,
 		name       => 'view.full_screen',
 		label      => Wx::gettext('&Full Screen'),
+		comment    => Wx::gettext('Set Padre in full screen mode'),
 		shortcut   => 'F11',
 		menu_event => sub {
 			if ( $_[0]->IsFullScreen ) {
