@@ -77,6 +77,11 @@ No support is available
 
 =head1 AUTHOR
 
-Copyright 2009 Anonymous.
+Copyright 2009
+[%- IF config.identity_name -%]
+ [% config.identity_name %]
+[%- ELSE -%]
+ Anonymous
+[%- END %].
 
 =cut
